@@ -1,6 +1,8 @@
 import json
 import os
 from socket import gethostname
+from dataclasses import dataclass, fields
+from typing import List, Dict
 
 from firexapp.application import get_app_tasks
 from firexapp.common import silent_mkdir, create_link
@@ -12,6 +14,21 @@ from firexapp.engine.celery import app
 
 logger = get_task_logger(__name__)
 
+@dataclass
+class FireXRunData:
+    completed: bool
+    chain: List[str]
+    firex_id: str
+    logs_path: str
+    submission_host: str
+    submission_dir: str
+    submission_cmd: List[str]
+    # TODO: the following default is temporary to workaround
+    # a testing chicken-and-egg problem. It should be removed
+    # after 25/11/2021
+    viewers: Dict[str, str] = None
+    results: Dict = None
+    revoked: bool = False
 
 class FireXJsonReportGenerator(ReportGenerator):
     formatters = ('json',)
@@ -31,9 +48,9 @@ class FireXJsonReportGenerator(ReportGenerator):
                 'submission_cmd': original_cli or list(argv),
                 }
 
-        viewers = uid.viewers
-        if viewers:
-            data.update(viewers)
+        viewers = uid.viewers or {}
+        data.update(viewers)
+        data['viewers'] = viewers
 
         return data
 
@@ -53,6 +70,7 @@ class FireXJsonReportGenerator(ReportGenerator):
         data = self.get_common_run_data(uid=uid, chain=chain, submission_dir=submission_dir, argv=argv,
                                         original_cli=original_cli)
         data['completed'] = False
+        data['revoked'] = False
         report_file = os.path.join(uid.logs_dir, self.reporter_dirname, self.initial_report_filename)
         self.write_report_file(data, report_file)
 
@@ -70,11 +88,13 @@ class FireXJsonReportGenerator(ReportGenerator):
                 logger.debug(f'{json_file} link already exist; '
                              f'post_run must have already created the link to {report_link}')
 
-    def post_run_report(self, uid, chain, root_id, submission_dir, argv, original_cli=None, json_file=None, **kwargs):
+    def post_run_report(self, uid, chain, root_id, submission_dir, argv, original_cli=None, json_file=None,
+                        run_revoked=False, **kwargs):
         data = self.get_common_run_data(uid=uid, chain=chain, submission_dir=submission_dir, argv=argv,
                                         original_cli=original_cli)
         data['completed'] = True
         data['results'] = get_results(root_id)
+        data['revoked'] = run_revoked
         report_file = os.path.join(uid.logs_dir, self.reporter_dirname, self.completion_report_filename)
 
         self.write_report_file(data, report_file)
@@ -99,3 +119,14 @@ def get_completion_report_data(logs_dir):
                                FireXJsonReportGenerator.completion_report_filename)
     with open(report_file) as f:
         return json.load(fp=f)
+
+def load_completion_report(json_file) -> FireXRunData:
+    assert os.path.isfile(json_file), f"File doesn't exist: {json_file}"
+
+    with open(json_file) as f:
+        run_dict = json.load(fp=f)
+
+    field_names = {f.name for f in fields(FireXRunData)}
+    filtered_run_dict = {k: v for k, v in run_dict.items() if k in field_names}
+    # TODO: consider using dacite library instead.
+    return FireXRunData(**filtered_run_dict)
\ No newline at end of file
