@@ -14,7 +14,7 @@ from shutil import copyfile
 from contextlib import contextmanager
 
 from celery.exceptions import NotRegistered
-from firexapp.discovery import get_all_pkg_versions
+from firexapp.discovery import get_all_pkg_versions_str
 from firexapp.engine.logging import add_hostname_to_log_records
 
 from firexkit.result import wait_on_async_results, disable_async_result, ChainRevokedException, \
@@ -129,8 +129,7 @@ class SubmitBaseApp:
 
     @staticmethod
     def log_firex_pkgs_versions():
-        pkg_version_info_str = [f'\t - {p_info}' for p_info in get_all_pkg_versions()]
-        logger.debug('FireX Packages:\n' + '\n'.join(pkg_version_info_str))
+        logger.debug(get_all_pkg_versions_str())
 
     def create_submit_parser(self, sub_parser):
         submit_parser = sub_parser.add_parser("submit",
@@ -172,7 +171,7 @@ class SubmitBaseApp:
         return submit_parser
 
     def convert_chain_args(self, chain_args) -> dict:
-        with self.graceful_exit_on_failure("The arguments you provided have the following errors"):
+        with self.graceful_exit_on_failure("The arguments you provided have errors."):
             return InputConverter.convert(**chain_args)
 
     def run_submit(self, args, others):
@@ -526,13 +525,15 @@ class SubmitBaseApp:
         if self.uid:
             self.copy_submission_log()
 
-    def self_destruct(self, chain_details=None, reason=None):
+    def self_destruct(self, chain_details=None, reason=None, run_revoked=False):
         if chain_details:
             chain_result, chain_args = chain_details
             try:
                 logger.debug("Generating reports")
                 from firexapp.submit.reporting import ReportersRegistry
-                ReportersRegistry.post_run_report(results=chain_result, kwargs=chain_args)
+                ReportersRegistry.post_run_report(results=chain_result,
+                                                  kwargs=chain_args,
+                                                  run_revoked=run_revoked)
                 logger.debug('Reports successfully generated')
             except Exception:
                 # Under no circumstances should report generation prevent celery and broker cleanup
